@@ -58,7 +58,9 @@ for cp_src, cp_dst_dir_fmt in [
 	print 'Info:  cp %s' % cp_src
 	os.system( 'cp -f %s tmp/%s' % (cp_src, cp_dst_dir_fmt % locals()) )
 
-os.system( 'gzip tmp/ROOT/usr/local/workbench/support/libdb-4.3.so' )
+has_libdb = os.path.exists( 'tmp/ROOT/usr/local/workbench/support/libdb-4.3.so' )
+if has_libdb:
+    os.system( 'gzip tmp/ROOT/usr/local/workbench/support/libdb-4.3.so' )
 
 print 'Info: Create tmp/SPECS/workbench.spec'
 f = file('tmp/SPECS/workbench.spec','w')
@@ -68,14 +70,14 @@ Version:	%(wb_version_package_string)s
 Group:		Development/Libraries
 Release:	%(wb_version_package_release_string)s
 Summary:	pysvn WorkBench %(wb_version_string)s for Subversion %(svn_version_string)s
-License:	Apache Software License, Version 1.1 - Copyright Barry A. Scott (c) 2003-2006
+License:	Apache Software License, Version 1.1 - Copyright Barry A. Scott (c) 2003-2007
 Packager:	Barry A. Scott <barry@barrys-emacs.org>
 AutoReqProv:	no
 Requires:	libsvn_client-1.so.0
 %%description
 PySVN WorkBench %(wb_version_string)s for Subversion %(svn_version_string)s
 
-Copyright Barry A. Scott (c) 2003-2006
+Copyright Barry A. Scott (c) 2003-2007
 
 mailto:barry@barrys-emacs.org
 http://pysvn.tigris.org
@@ -89,8 +91,10 @@ http://pysvn.tigris.org
 %%post
 rm -f /usr/local/bin/workbench
 ln -f -s /usr/local/workbench/wb /usr/local/bin/workbench
-gzip -d -c </usr/local/workbench/support/libdb-4.3.so.gz >/usr/local/workbench/support/libdb-4.3.so
-
+if [ -e /usr/local/workbench/support/libdb-4.3.so.gz ]
+then
+    gzip -d -c </usr/local/workbench/support/libdb-4.3.so.gz >/usr/local/workbench/support/libdb-4.3.so
+fi
 mkdir -p /usr/local/share/workbench
 ln -f -s /usr/local/workbench/WorkBench.html /usr/local/share/workbench
 %%postun
