@@ -11,9 +11,8 @@ import pysvn
 import time
 import subprocess
 
-
 proc = subprocess.Popen(
-            'uname -p',
+            'uname -m',
             shell=True,
             close_fds=True,
             stdin=subprocess.PIPE,
@@ -28,6 +27,7 @@ def os_system( cmd ):
     sys.stdout.flush()
     if os.system( '%s 2>&1' % cmd ) == 0:
         return
+
     print 'Error: command failed'
     sys.exit( 1 )
 
@@ -68,7 +68,6 @@ for cp_src, cp_dst_dir_fmt in [
     ]:
     if os.path.exists( cp_src ):
         cmd = 'cp -f %s tmp/%s' % (cp_src, cp_dst_dir_fmt % locals())
-        print 'Info: %s' % cmd
         os_system( cmd )
     else:
         print 'Error: cannot find %s' % cp_src
@@ -82,7 +81,7 @@ else:
     os_system( 'cp ../../Docs/WorkBench_files/* tmp/%s/WorkBench_files' % pkg_filename )
 
 print 'Info: Create tmp/ReadMe.html'
-f = file('tmp/ReadMe.html','w')
+f = open('tmp/ReadMe.html','w')
 f.write('''<html>
 <body>
 <h1>pysvn WorkBench %(wb_version_string)s for Mac OS X and Subversion %(svn_version_string)s</h1>
