@@ -53,6 +53,13 @@ for filename in os.listdir( docs_files_dir ):
         f.write( 'Source: "..\\..\\..\\docs\\WorkBench_files\\%s"; DestDir: "{app}\\WorkBench_files";\n'
                     % filename )
 
+locale_files_dir = '..\\..\\Source\\locale'
+
+for lang in os.listdir( locale_files_dir ):
+    f.write( 'Source: "..\\..\\..\\Source\\locale\\%s\LC_MESSAGES\\pysvn_workbench.mo"; '
+                'DestDir: "{app}\\locale\\%s\LC_MESSAGES";\n'
+                    % (lang, lang) )
+
 f.close()
 
 print 'Info: Create setup_copy.cmd'
