@@ -18,14 +18,9 @@ then
 fi
 PYTHONW=${DIRNAME}pythonw${SUFFIX}
 
-if [ -e /System/Library/CoreServices/SystemVersion.plist ]
-then
-    ARCH_CMD="arch -i386"
-fi
-
 if [ -e ${PYTHONW} ]
 then
-    ${ARCH_CMD} ${PYTHONW} wb_main.py $*
+    ${PYTHONW} wb_main.py $*
 else
-    ${ARCH_CMD} ${PYTHON} wb_main.py $*
+    ${PYTHON} wb_main.py $*
 fi
