@@ -166,7 +166,10 @@ class WbApp(wx.App):
         return not self.__debug_noredirect
 
     def eventWrapper( self, function ):
-        return EventScheduling( self, function )
+        return EventScheduling( self, function, update=False )
+
+    def eventUpdateWrapper( self, function ):
+        return EventScheduling( self, function, update=True )
 
     def isMainThread( self ):
         'return true if the caller is running on the main thread'
@@ -180,6 +183,7 @@ class WbApp(wx.App):
     _all_mac_locales = {
         '0:0':  'en_GB.utf-8',
         '0:3':  'de_DE.utf-8',
+        '0:4':  'it_IT.utf-8',
         }
 
     def initLocale( self ):
@@ -198,7 +202,7 @@ class WbApp(wx.App):
             if '__CF_USER_TEXT_ENCODING' in os.environ:
                 self.log.info( 'setlocale from __CF_USER_TEXT_ENCODING %s' % os.environ['__CF_USER_TEXT_ENCODING'] )
                 lang_code = os.environ['__CF_USER_TEXT_ENCODING'].split( ':', 1 )[1]
-                locale.setlocale( locale.LC_ALL, self._all_mac_locales.get( lang_code, '0:0' ) )
+                locale.setlocale( locale.LC_ALL, self._all_mac_locales.get( lang_code, 'en_GB.utf-8' ) )
                 return
 
         # generic Posix locale code
@@ -540,13 +544,16 @@ class AppBackgroundFunction:
                 (self.function.__module__, self.function.__name__) )
 
 class EventScheduling:
-    def __init__( self, app, function ):
+    def __init__( self, app, function, update ):
         self.app = app
         self.function = function
+        self.update = update
 
     def __call__( self, *args, **kwds ):
-        self.app.trace.info( 'EventScheduling<%s.%s>.__call__()' %
-                (self.function.__module__, self.function.__name__) )
+        if not self.update:
+            self.app.trace.info( 'EventScheduling<%s.%s>.__call__()' %
+                    (self.function.__module__, self.function.__name__) )
+
         try:
             # call the function
             result = self.function( *args, **kwds )
