@@ -267,20 +267,20 @@ class WbFrame(wx.Frame):
             wx.EVT_UPDATE_UI( event_source, wb_ids.id_View_OnlyChanges, try_wrapper( self.OnUpdateViewOnlyChanges ) )
 
             wx.EVT_MENU( event_source, wb_ids.id_SP_EditCopy, self.app.eventWrapper( self.OnSpEditCopy ) )
-            wx.EVT_UPDATE_UI( event_source, wb_ids.id_SP_EditCopy, self.app.eventWrapper( self.OnUpdateUiSpEditCopy ) )
+            wx.EVT_UPDATE_UI( event_source, wb_ids.id_SP_EditCopy, self.app.eventUpdateWrapper( self.OnUpdateUiSpEditCopy ) )
             wx.EVT_MENU( event_source, wb_ids.id_SP_EditCut, self.app.eventWrapper( self.OnSpEditCut ) )
-            wx.EVT_UPDATE_UI( event_source, wb_ids.id_SP_EditCut, self.app.eventWrapper( self.OnUpdateUiSpEditCut ) )
+            wx.EVT_UPDATE_UI( event_source, wb_ids.id_SP_EditCut, self.app.eventUpdateWrapper( self.OnUpdateUiSpEditCut ) )
             wx.EVT_MENU( event_source, wb_ids.id_SP_EditPaste, self.app.eventWrapper( self.OnSpEditPaste ) )
-            wx.EVT_UPDATE_UI( event_source, wb_ids.id_SP_EditPaste, self.app.eventWrapper( self.OnUpdateUiSpEditPaste ) )
+            wx.EVT_UPDATE_UI( event_source, wb_ids.id_SP_EditPaste, self.app.eventUpdateWrapper( self.OnUpdateUiSpEditPaste ) )
 
             wx.EVT_MENU( event_source, wb_ids.id_View_Diff_WbDiff, self.app.eventWrapper( self.OnViewDiffWbDiff ) )
-            wx.EVT_UPDATE_UI( event_source, wb_ids.id_View_Diff_WbDiff, self.app.eventWrapper( self.OnUpdateUiViewDiffWbDiff ) )
+            wx.EVT_UPDATE_UI( event_source, wb_ids.id_View_Diff_WbDiff, self.app.eventUpdateWrapper( self.OnUpdateUiViewDiffWbDiff ) )
             wx.EVT_MENU( event_source, wb_ids.id_View_Diff_ExtGuiDiff, self.app.eventWrapper( self.OnViewDiffExtGuiDiff ) )
-            wx.EVT_UPDATE_UI( event_source, wb_ids.id_View_Diff_ExtGuiDiff, self.app.eventWrapper( self.OnUpdateUiViewDiffExtGuiDiff ) )
+            wx.EVT_UPDATE_UI( event_source, wb_ids.id_View_Diff_ExtGuiDiff, self.app.eventUpdateWrapper( self.OnUpdateUiViewDiffExtGuiDiff ) )
             wx.EVT_MENU( event_source, wb_ids.id_View_Diff_ExtTextDiff, self.app.eventWrapper( self.OnViewDiffExtTextDiff ) )
-            wx.EVT_UPDATE_UI( event_source, wb_ids.id_View_Diff_ExtTextDiff, self.app.eventWrapper( self.OnUpdateUiViewDiffExtTextDiff ) )
+            wx.EVT_UPDATE_UI( event_source, wb_ids.id_View_Diff_ExtTextDiff, self.app.eventUpdateWrapper( self.OnUpdateUiViewDiffExtTextDiff ) )
             wx.EVT_MENU( event_source, wb_ids.id_View_Diff_SvnDiff, self.app.eventWrapper( self.OnViewDiffSvnDiff ) )
-            wx.EVT_UPDATE_UI( event_source, wb_ids.id_View_Diff_SvnDiff, self.app.eventWrapper( self.OnUpdateUiViewDiffSvnDiff ) )
+            wx.EVT_UPDATE_UI( event_source, wb_ids.id_View_Diff_SvnDiff, self.app.eventUpdateWrapper( self.OnUpdateUiViewDiffSvnDiff ) )
 
         wx.EVT_MENU( self, wb_ids.id_File_Edit, try_wrapper( self.OnFileEdit ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_File_Edit, try_wrapper( self.OnUpdateUiFileEdit ) )
@@ -293,80 +293,80 @@ class WbFrame(wx.Frame):
         wx.EVT_UPDATE_UI( self, wb_ids.id_File_Browser, try_wrapper( self.OnUpdateUiFileBrowser ) )
 
         wx.EVT_MENU( self, wb_ids.id_SP_Add, self.app.eventWrapper( self.OnSpAdd ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Add, self.app.eventWrapper( self.OnUpdateUiSpAdd ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Add, self.app.eventUpdateWrapper( self.OnUpdateUiSpAdd ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Annotate, self.app.eventWrapper( self.OnSpAnnotate ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Annotate, self.app.eventWrapper( self.OnUpdateUiSpAnnotate ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Annotate, self.app.eventUpdateWrapper( self.OnUpdateUiSpAnnotate ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Checkin, self.app.eventWrapper( self.OnSpCheckin ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Checkin, self.app.eventWrapper( self.OnUpdateUiSpCheckin ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Checkin, self.app.eventUpdateWrapper( self.OnUpdateUiSpCheckin ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Checkout, self.app.eventWrapper( self.OnSpCheckout ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Checkout, self.app.eventWrapper( self.OnUpdateUiSpCheckout ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Checkout, self.app.eventUpdateWrapper( self.OnUpdateUiSpCheckout ) )
         wx.EVT_MENU( self, wb_ids.id_SP_CheckoutTo, self.app.eventWrapper( self.OnSpCheckoutTo ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_CheckoutTo, self.app.eventWrapper( self.OnUpdateUiSpCheckoutTo ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_CheckoutTo, self.app.eventUpdateWrapper( self.OnUpdateUiSpCheckoutTo ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Cleanup, self.app.eventWrapper( self.OnSpCleanup ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Cleanup, self.app.eventWrapper( self.OnUpdateUiSpCleanup ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Cleanup, self.app.eventUpdateWrapper( self.OnUpdateUiSpCleanup ) )
         wx.EVT_MENU( self, wb_ids.id_SP_CreateTag, self.app.eventWrapper( self.OnSpCreateTag ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_CreateTag, self.app.eventWrapper( self.OnUpdateUiSpCreateTag ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_CreateTag, self.app.eventUpdateWrapper( self.OnUpdateUiSpCreateTag ) )
         wx.EVT_MENU( self, wb_ids.id_SP_CreateBranch, self.app.eventWrapper( self.OnSpCreateBranch ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_CreateBranch, self.app.eventWrapper( self.OnUpdateUiSpCreateBranch ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_CreateBranch, self.app.eventUpdateWrapper( self.OnUpdateUiSpCreateBranch ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Delete, self.app.eventWrapper( self.OnSpDelete ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Delete, self.app.eventWrapper( self.OnUpdateUiSpDelete ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Delete, self.app.eventUpdateWrapper( self.OnUpdateUiSpDelete ) )
         wx.EVT_MENU( self, wb_ids.id_SP_DiffMineNew, self.app.eventWrapper( self.OnSpDiffMineNew ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffMineNew, self.app.eventWrapper( self.OnUpdateUiSpDiffMineNew ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffMineNew, self.app.eventUpdateWrapper( self.OnUpdateUiSpDiffMineNew ) )
         wx.EVT_MENU( self, wb_ids.id_SP_DiffOldMine, self.app.eventWrapper( self.OnSpDiffOldMine ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffOldMine, self.app.eventWrapper( self.OnUpdateUiSpDiffOldMine ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffOldMine, self.app.eventUpdateWrapper( self.OnUpdateUiSpDiffOldMine ) )
         wx.EVT_MENU( self, wb_ids.id_SP_DiffOldNew, self.app.eventWrapper( self.OnSpDiffOldNew ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffOldNew, self.app.eventWrapper( self.OnUpdateUiSpDiffOldNew ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffOldNew, self.app.eventUpdateWrapper( self.OnUpdateUiSpDiffOldNew ) )
         wx.EVT_MENU( self, wb_ids.id_SP_DiffWorkBase, self.app.eventWrapper( self.OnSpDiffWorkBase ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffWorkBase, self.app.eventWrapper( self.OnUpdateUiSpDiffWorkBase ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffWorkBase, self.app.eventUpdateWrapper( self.OnUpdateUiSpDiffWorkBase ) )
         wx.EVT_MENU( self, wb_ids.id_SP_DiffWorkHead, self.app.eventWrapper( self.OnSpDiffWorkHead ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffWorkHead, self.app.eventWrapper( self.OnUpdateUiSpDiffWorkHead ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffWorkHead, self.app.eventUpdateWrapper( self.OnUpdateUiSpDiffWorkHead ) )
         wx.EVT_MENU( self, wb_ids.id_SP_DiffWorkBranchOriginBase, self.app.eventWrapper( self.OnSpDiffWorkBranchOriginBase ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffWorkBranchOriginBase, self.app.eventWrapper( self.OnUpdateUiSpDiffWorkBranchOriginBase ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffWorkBranchOriginBase, self.app.eventUpdateWrapper( self.OnUpdateUiSpDiffWorkBranchOriginBase ) )
         wx.EVT_MENU( self, wb_ids.id_SP_DiffWorkBranchOriginHead, self.app.eventWrapper( self.OnSpDiffWorkBranchOriginHead ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffWorkBranchOriginHead, self.app.eventWrapper( self.OnUpdateUiSpDiffWorkBranchOriginHead ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_DiffWorkBranchOriginHead, self.app.eventUpdateWrapper( self.OnUpdateUiSpDiffWorkBranchOriginHead ) )
         wx.EVT_MENU( self, wb_ids.id_SP_History, self.app.eventWrapper( self.OnSpHistory ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_History, self.app.eventWrapper( self.OnUpdateUiSpHistory ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_History, self.app.eventUpdateWrapper( self.OnUpdateUiSpHistory ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Info, self.app.eventWrapper( self.OnSpInfo ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Info, self.app.eventWrapper( self.OnUpdateUiSpInfo ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Info, self.app.eventUpdateWrapper( self.OnUpdateUiSpInfo ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Lock, self.app.eventWrapper( self.OnSpLock ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Lock, self.app.eventWrapper( self.OnUpdateUiSpLock ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Lock, self.app.eventUpdateWrapper( self.OnUpdateUiSpLock ) )
         wx.EVT_MENU( self, wb_ids.id_SP_NewFile, self.app.eventWrapper( self.OnSpNewFile ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_NewFile, self.app.eventWrapper( self.OnUpdateUiSpNewFile ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_NewFile, self.app.eventUpdateWrapper( self.OnUpdateUiSpNewFile ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Mkdir, self.app.eventWrapper( self.OnSpMkdir ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Mkdir, self.app.eventWrapper( self.OnUpdateUiSpMkdir ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Mkdir, self.app.eventUpdateWrapper( self.OnUpdateUiSpMkdir ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Properties, self.app.eventWrapper( self.OnSpProperties ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Properties, self.app.eventWrapper( self.OnUpdateUiSpProperties ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Properties, self.app.eventUpdateWrapper( self.OnUpdateUiSpProperties ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Rename, self.app.eventWrapper( self.OnSpRename ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Rename, self.app.eventWrapper( self.OnUpdateUiSpRename ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Rename, self.app.eventUpdateWrapper( self.OnUpdateUiSpRename ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Resolved, self.app.eventWrapper( self.OnSpResolved ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Resolved, self.app.eventWrapper( self.OnUpdateUiSpResolved ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Resolved, self.app.eventUpdateWrapper( self.OnUpdateUiSpResolved ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Revert, self.app.eventWrapper( self.OnSpRevert ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Revert, self.app.eventWrapper( self.OnUpdateUiSpRevert ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Revert, self.app.eventUpdateWrapper( self.OnUpdateUiSpRevert ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Unlock, self.app.eventWrapper( self.OnSpUnlock ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Unlock, self.app.eventWrapper( self.OnUpdateUiSpUnlock ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Unlock, self.app.eventUpdateWrapper( self.OnUpdateUiSpUnlock ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Update, self.app.eventWrapper( self.OnSpUpdate ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Update, self.app.eventWrapper( self.OnUpdateUiSpUpdate ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Update, self.app.eventUpdateWrapper( self.OnUpdateUiSpUpdate ) )
         wx.EVT_MENU( self, wb_ids.id_SP_UpdateTo, self.app.eventWrapper( self.OnSpUpdateTo ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_UpdateTo, self.app.eventWrapper( self.OnUpdateUiSpUpdateTo ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_UpdateTo, self.app.eventUpdateWrapper( self.OnUpdateUiSpUpdateTo ) )
 
         if wb_subversion_utils.version_info.has_upgrade:
             wx.EVT_MENU( self, wb_ids.id_SP_Upgrade, self.app.eventWrapper( self.OnSpUpgrade ) )
-            wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Upgrade, self.app.eventWrapper( self.OnUpdateUiSpUpgrade ) )
+            wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Upgrade, self.app.eventUpdateWrapper( self.OnUpdateUiSpUpgrade ) )
 
         wx.EVT_MENU( self, wb_ids.id_SP_Report_Updates, self.app.eventWrapper( self.OnSpReportUpdates ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Report_Updates, self.app.eventWrapper( self.OnUpdateUiSpReportUpdates ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Report_Updates, self.app.eventUpdateWrapper( self.OnUpdateUiSpReportUpdates ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Report_LocksWc, self.app.eventWrapper( self.OnSpReportLocksWc ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Report_LocksWc, self.app.eventWrapper( self.OnUpdateUiSpReportLocksWc ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Report_LocksWc, self.app.eventUpdateWrapper( self.OnUpdateUiSpReportLocksWc ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Report_LocksRepos, self.app.eventWrapper( self.OnSpReportLocksRepos ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Report_LocksRepos, self.app.eventWrapper( self.OnUpdateUiSpReportLocksRepos ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Report_LocksRepos, self.app.eventUpdateWrapper( self.OnUpdateUiSpReportLocksRepos ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Report_BranchChanges, self.app.eventWrapper( self.OnSpReportBranchChanges ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Report_BranchChanges, self.app.eventWrapper( self.OnUpdateUiSpReportBranchChanges ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Report_BranchChanges, self.app.eventUpdateWrapper( self.OnUpdateUiSpReportBranchChanges ) )
 
         wx.EVT_MENU( self, wb_ids.id_Project_Add, try_wrapper( self.app.eventWrapper( self.tree_panel.OnProjectAdd ) ) )
         wx.EVT_MENU( self, wb_ids.id_Project_Update, try_wrapper( self.app.eventWrapper( self.tree_panel.OnProjectUpdate ) ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_Project_Update, try_wrapper( self.app.eventWrapper( self.OnUpdateUiProjectUpdateOrDelete ) ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_Project_Update, try_wrapper( self.app.eventUpdateWrapper( self.OnUpdateUiProjectUpdateOrDelete ) ) )
         wx.EVT_MENU( self, wb_ids.id_Project_Delete, try_wrapper( self.app.eventWrapper( self.tree_panel.OnProjectDelete ) ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_Project_Delete, try_wrapper( self.app.eventWrapper( self.OnUpdateUiProjectUpdateOrDelete ) ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_Project_Delete, try_wrapper( self.app.eventUpdateWrapper( self.OnUpdateUiProjectUpdateOrDelete ) ) )
 
         wx.EVT_MENU( self, wb_ids.id_Bookmark_Add, try_wrapper( self.OnBookmarkAdd ) )
         wx.EVT_MENU( self, wb_ids.id_Bookmark_Manage, try_wrapper( self.OnBookmarkManage ) )
@@ -419,18 +419,19 @@ class WbFrame(wx.Frame):
         toolbar.Realize()
 
     def setEventHandler( self, handler ):
+        self.app.log.debug( 'setEventHandler to %r' % (handler,) )
         if wb_config.debug_selection:
             print 'ZF: setEventHandler from %r' % self.event_handler
             print 'ZF: setEventHandler   to %r' % handler
             import wb_debug
             wb_debug.printStack( '     ' )
 
-        self.app.debugShowCallers( 20 )
-
         if self.event_handler is not handler:
             self.event_handler = handler
             self.clearUpdateUiState()
 
+        self.app.log.debug( 'self.ui_state_focus %r' % (self.ui_state_focus,) )
+
     def clearEventHandler( self ):
         self.app.log.debug( 'clearEventHandler from %r to None' % self.event_handler )
         if wb_config.debug_selection: print 'ZF: clearEventHandler from %r to None' % self.event_handler
@@ -723,8 +724,6 @@ class WbFrame(wx.Frame):
 
     def OnUpdateUiFileEdit( self, event ):
         self.getUpdateUiState()
-        #self.ui_state_list.printState('OnUpdateUiFileEdit')
-        #print 'isListHandler() => %r' % self.event_handler.isListHandler()
         event.Enable( self.ui_state_list.file_exists and self.event_handler.isListHandler())
 
     def OnShellOpen( self, event ):
@@ -1071,7 +1070,7 @@ class WbFrame(wx.Frame):
         self.getUpdateUiState()
 
         # this is a tree only command
-        event.Enable( self.list_panel.list_handler.project_info.need_upgrade )
+        event.Enable( self.list_panel.list_handler is not None and self.list_panel.list_handler.project_info.need_upgrade )
 
     #----------------------------------------
     def Sp_Dispatch( self, sp_func_name ):
@@ -1093,13 +1092,13 @@ class WbFrame(wx.Frame):
         if self.ui_state_tree is None:
             self.ui_state_tree = self.tree_panel.getUpdateUiState()
             if self.ui_state_tree is None:
-                self.ui_state_tree = wb_tree_panel.TreeState( True )
+                self.ui_state_tree = wb_tree_panel.TreeState( None, True )
             all_debug_messages.append( 'tree place_holder %s' % self.ui_state_tree.place_holder )
 
         if self.ui_state_list is None:
             self.ui_state_list = self.list_panel.getUpdateUiState()
             if self.ui_state_list is None:
-                self.ui_state_list = wb_list_panel_common.ListItemState( True )
+                self.ui_state_list = wb_list_panel_common.ListItemState( None, True )
             all_debug_messages.append( 'list place_holder %s' % self.ui_state_list.place_holder )
 
         if self.ui_state_focus is None:
@@ -1114,6 +1113,8 @@ class WbFrame(wx.Frame):
                 self.ui_state_focus = self.ui_state_list
             all_debug_messages.append( 'focus place_holder %s' % self.ui_state_focus.place_holder )
 
+            self.ui_state_focus.debugPrintState( self.app.log.debug, 'getUpdateUiState set ui_state_focus' )
+
         if wb_config.debug_selection and len(all_debug_messages)>0:
             print 'ZF: getUpdateUiState() ------------------------------'
             for message in all_debug_messages:
