@@ -1,7 +1,7 @@
 '''
 
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2011 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -28,3 +28,11 @@ def getLocalePath( app ):
 
 def getNullDevice():
     return 'NUL'
+
+uPathExists = os.path.exists
+uPathIsdir = os.path.isdir
+uAccess = os.access
+uRemove = os.remove
+uRename = os.rename
+uOpen = open
+uChdir = os.chdir
