@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2010 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -18,6 +18,7 @@ import wb_shell_commands
 import wb_dialogs
 import wb_tree_panel
 import wb_toolbars
+import wb_platform_specific
 
 class PreferencesDialog( wx.Dialog ):
     def __init__( self, parent, app ):
@@ -168,14 +169,14 @@ class EditorPage(PagePanel):
         # otherwise it must exist
         valid = False
         if wx.Platform == '__WXMAC__':
-            valid = (os.access( self.text_ctrl_editor.GetValue(), os.X_OK )
-                or not os.path.isdir( self.text_ctrl_editor.GetValue() ) )
+            valid = (wb_platform_specific.uAccess( self.text_ctrl_editor.GetValue(), os.X_OK )
+                or not wb_platform_specific.uPathIsdir( self.text_ctrl_editor.GetValue() ) )
         elif wx.Platform == '__WXMSW__':
-            valid = (os.path.exists( self.text_ctrl_editor.GetValue() )
-                or not os.path.isdir( self.text_ctrl_editor.GetValue() ) )
+            valid = (wb_platform_specific.uPathExists( self.text_ctrl_editor.GetValue() )
+                or not wb_platform_specific.uPathIsdir( self.text_ctrl_editor.GetValue() ) )
         else:
-            valid = (os.access( self.text_ctrl_editor.GetValue(), os.X_OK )
-                or not os.path.isdir( self.text_ctrl_editor.GetValue() ) )
+            valid = (wb_platform_specific.uAccess( self.text_ctrl_editor.GetValue(), os.X_OK )
+                or not wb_platform_specific.uPathIsdir( self.text_ctrl_editor.GetValue() ) )
 
         if not valid:
             wx.MessageBox(
