@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2010 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -12,7 +12,10 @@
 '''
 import wx
 import wx.wizard
+
 import wb_source_control_providers
+import wb_platform_specific
+
 import pysvn
 import os
 
@@ -143,7 +146,7 @@ class ProjectDialog(wx.Dialog):
         wc_path = os.path.expanduser( self.wc_path_ctrl.GetValue().strip() )
 
         url = None
-        if os.path.exists( wc_path ):
+        if wb_platform_specific.uPathExists( wc_path ):
             try:
                 info = self.client.info( wc_path )
                 url = info.url
@@ -508,14 +511,14 @@ class WorkingCopyExistsPage(TitledPage):
         state.wc_path = os.path.abspath( os.path.expanduser( self.wc_path_ctrl.GetValue().strip() ) )
         state.url_path = self.url_ctrl.GetLabel().strip()
 
-        if not os.path.exists( state.wc_path ):
+        if not wb_platform_specific.uPathExists( state.wc_path ):
             wx.MessageBox( T_('Path %s\n'
                     'Does not exist\n'
                     'Choose an existing subversion working copy directory')
                     % state.wc_path, style=wx.OK|wx.ICON_ERROR );
             return False
 
-        if not os.path.isdir( state.wc_path ):
+        if not wb_platform_specific.uPathIsdir( state.wc_path ):
             wx.MessageBox( T_('Path %s\n'
                     'Is not a directory\n'
                     'Choose an existing subversion working copy directory')
@@ -557,7 +560,7 @@ class WorkingCopyExistsPage(TitledPage):
         wc_path = os.path.expanduser( wc_path )
 
         url = None
-        if os.path.exists( wc_path ):
+        if wb_platform_specific.uPathExists( wc_path ):
             try:
                 info = self.parent.client_pi.client_fg.info( wc_path )
                 url = info.url
@@ -665,8 +668,8 @@ class WorkingCopyCreatePage(TitledPage):
                     style=wx.OK|wx.ICON_ERROR );
             return False
 
-        if os.path.exists( state.wc_path ):
-            if not os.path.isdir( state.wc_path ):
+        if wb_platform_specific.uPathExists( state.wc_path ):
+            if not wb_platform_specific.uPathIsdir( state.wc_path ):
                 wx.MessageBox( T_('Path %s\n'
                         'Is not a directory\n'
                         'Choose a directory that is empty and not in use by subversion')
