@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2005-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2005-2010 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -13,8 +13,10 @@
 import locale
 import codecs
 
+import wb_platform_specific
+
 def readFileContentsAsUnicode( filename ):
-    f = file( filename, 'r' )
+    f = wb_platform_specific.uOpen( filename, 'r' )
     contents = f.read()
     f.close()
 
@@ -37,15 +39,22 @@ def encodingFromContents( contents ):
     if( len(contents) > len(codecs.BOM_UTF8)
     and contents[0:len(codecs.BOM_UTF8)] == codecs.BOM_UTF8 ):
         encoding = 'utf-8'
+
     elif( len(contents) > len(codecs.BOM_UTF16_LE)
     and contents[0:len(codecs.BOM_UTF16_LE)] in [codecs.BOM_UTF16_LE, codecs.BOM_UTF16_BE]):
         encoding = 'utf-16'
+
     elif( len(contents) > len(codecs.BOM_UTF32_LE)
     and contents[0:len(codecs.BOM_UTF32_LE)] in [codecs.BOM_UTF32_LE, codecs.BOM_UTF32_BE]):
         encoding = 'utf-32'
+
     else:
         encoding = locale.getdefaultlocale()[1]
 
+        # Mac says mac-roman when utf-8 is what is required
+        if encoding == 'mac-roman':
+            encoding = 'utf-8'
+
     if encoding is None:
         encoding = 'iso8859-1'
 
