@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2010 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -15,6 +15,8 @@ import signal
 import subprocess
 import xml.sax.saxutils
 
+import wb_platform_specific
+
 __sigchld_handler_installed = False
 
 def getTerminalProgramList():
@@ -24,12 +26,12 @@ def getFileBrowserProgramList():
     return ['Finder']
 
 def GuiDiffFiles( app, options ):
-    cmd_line = "'%s' %s &" % (app.prefs.getDiffTool().gui_diff_tool, options)
+    cmd_line = u"'%s' %s &" % (app.prefs.getDiffTool().gui_diff_tool, options)
     app.log.info( cmd_line )
     __run_command_with_output( cmd_line )
 
 def ShellDiffFiles( app, options ):
-    cmd_line = "'%s' %s" % (app.prefs.getDiffTool().shell_diff_tool, options)
+    cmd_line = u"'%s' %s" % (app.prefs.getDiffTool().shell_diff_tool, options)
     app.log.info( cmd_line )
     return __run_command_with_output( cmd_line )
 
@@ -38,30 +40,31 @@ def EditFile( app, project_info, filename ):
 
     if p.editor_image:
         if p.editor_options:
-            command_line = '"%s" %s "%s" &' % \
-                (p.editor_image, p.editor_options, filename)
+            command_line = (u'"%s" %s "%s" &' %
+                (p.editor_image, p.editor_options, filename))
         else:
-            command_line = '"%s" "%s" &' % \
-                (p.editor_image, filename)
+            command_line = (u'"%s" "%s" &' %
+                (p.editor_image, filename))
     else:
-        command_line = '"open" -e "%s" &' % filename
+        command_line = (u'"open" -e "%s" &' %
+                            (filename,))
 
     app.log.info( command_line )
     cur_dir = os.getcwd()
     try:
-        os.chdir( project_info.getWorkingDir() )
-        os.system( command_line )
+        wb_platform_specific.uChdir( project_info.getWorkingDir() )
+        os.system( command_line.encode( 'utf-8' ) )
     finally:
-        os.chdir( cur_dir )
+        wb_platform_specific.uChdir( cur_dir )
 
 def ShellOpen( app, project_info, filename ):
     app.log.info( T_('Open %s') % filename )
     cur_dir = os.getcwd()
     try:
-        os.chdir( project_info.getWorkingDir() )
-        __run_command_with_output( 'open "%s"' % filename )
+        wb_platform_specific.uChdir( project_info.getWorkingDir() )
+        __run_command_with_output( u'open "%s"' % (filename,) )
     finally:
-        os.chdir( cur_dir )
+        wb_platform_specific.uChdir( cur_dir )
 
 def CommandShell( app, project_info ):
     p = app.prefs.getShell()
@@ -83,13 +86,12 @@ def CommandShell_iTerm( app, project_info ):
         title.append( pi.project_name )
         pi = pi.parent
 
-    commands = 'cd "%s"' % working_dir
+    commands = u'cd "%s"' % working_dir
 
     if len( p.shell_init_command ) > 0:
-        commands = commands + ';. "%s"\n' % p.shell_init_command
+        commands = commands + u';. "%s"\n' % p.shell_init_command
 
-    f  = open( shell_script_filename, 'w' )
-    f.write( '''
+    contents = u'''
 tell application "iTerm"
     activate 
 
@@ -116,10 +118,13 @@ tell application "iTerm"
 
 end
 ''' %   (' '.join( title ).replace( '"', '\\"' )
-        ,commands.replace( '"', '\\"' )) )
+        ,commands.replace( '"', '\\"' ))
+
+    f = wb_platform_specific.uOpen( shell_script_filename, 'w' )
+    f.write( contents.encode( 'utf-8' ) )
     f.close()
 
-    command_line = '"osascript" "%s" &' % shell_script_filename
+    command_line = u'"osascript" "%s" &' % shell_script_filename
 
     app.log.info( command_line )
     __run_command_with_output( command_line )
@@ -137,13 +142,12 @@ def CommandShell_Terminal( app, project_info ):
         title.append( pi.project_name )
         pi = pi.parent
 
-    commands = 'cd "%s"' % working_dir
+    commands = u'cd "%s"' % working_dir
 
     if len( p.shell_init_command ) > 0:
         commands = commands + ';. "%s"\n' % p.shell_init_command
 
-    f  = open( shell_script_filename, 'w' )
-    f.write( '''<?xml version="1.0" encoding="UTF-8"?>
+    contents = u'''<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
@@ -158,16 +162,20 @@ def CommandShell_Terminal( app, project_info ):
     </array>
 </dict>
 </plist>
-''' % (xml.sax.saxutils.escape( ' '.join( title ) ), xml.sax.saxutils.escape( commands )) )
+''' %   (xml.sax.saxutils.escape( ' '.join( title ) )
+        ,xml.sax.saxutils.escape( commands ))
+
+    f  = wb_platform_specific.uOpen( shell_script_filename, 'w' )
+    f.write( contents.encode( 'utf-8' ) )
     f.close()
 
-    command_line = '"open" "%s" &' % shell_script_filename
+    command_line = u'"open" "%s" &' % shell_script_filename
 
     app.log.info( command_line )
     __run_command_with_output( command_line )
 
 def FileBrowser( app, project_info ):
-    command_line = 'open -a "Finder" "%s" &' % project_info.getWorkingDir()
+    command_line = u'open -a "Finder" "%s" &' % project_info.getWorkingDir()
 
     app.log.info( command_line )
     __run_command_with_output( command_line )
@@ -217,11 +225,11 @@ def _run_command( command_line ):
     print '%s, rc=%d' % (err_prefix, rc)
 
 def __run_command_with_output( command_line ):
-    err_prefix = 'error running %s' % command_line
+    err_prefix = u'error running %s' % command_line
 
     try:
         proc = subprocess.Popen(
-                    command_line,
+                    command_line.encode( 'utf-8' ),
                     shell=True,
                     close_fds=True,
                     stdin=subprocess.PIPE,
