@@ -538,7 +538,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         if len(all_rows) == 0:
             return None
 
-        state = wb_list_panel_common.ListItemState()
+        state = wb_list_panel_common.ListItemState( self.project_info )
 
         if self.project_info.need_upgrade:
             state.need_upgrade = True
@@ -619,8 +619,6 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
             if not text_reverable and not prop_revertable:
                 state.revertable = False
 
-        #state.printState( 'getState' )
-
         return state
 
     def getStatusFromRowOrStatus( self, row_or_status ):
