@@ -161,7 +161,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
                 return
 
         # see if we want to handle this action
-        if wb_subversion_utils.wc_notify_action_map[ arg_dict['action'] ] is None:
+        if wb_subversion_utils.wc_notify_action_lookup( arg_dict['action'] ) is None:
             return
 
         # reject updates for paths that have no change
@@ -170,12 +170,12 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         and arg_dict['prop_state'] == pysvn.wc_notify_state.unknown ):
             return
 
-        if wb_subversion_utils.wc_notify_type_map[ action ] == 'U':
+        if wb_subversion_utils.wc_notify_type_lookup( action ) == 'U':
             # count the interesting update event
             self.app.foregroundProcess( self.app.incProgress, () )
 
         # count the number of files in conflict
-        action_letter = wb_subversion_utils.wc_notify_action_map[ action ]
+        action_letter = wb_subversion_utils.wc_notify_action_lookup( action )
         if( arg_dict['content_state'] == pysvn.wc_notify_state.conflicted
         or arg_dict['prop_state'] == pysvn.wc_notify_state.conflicted ):
             action_letter = 'C'
@@ -311,6 +311,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         if len(self.all_files_status) > 0 and os.path.normcase( self.all_files_status[0].path ) == os.path.normcase( self.wc_path ):
             self.dir_status = self.all_files_status[0]
             del self.all_files_status[0]
+            self.app.log.debug( 'updateStatus() self.dir_status %r' % (self.dir_status,) )
 
         # filter show only the files that the user is interested in
         self.all_files_status = self.filterFilenames( self.all_files_status )
