@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2009 Barry A Scott.  All rights reserved.
+ Copyright (c) 2009-2011 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -23,7 +23,6 @@ import wb_list_panel_common
 import wb_subversion_diff
 import wb_subversion_utils
 import wb_subversion_list_handler_common
-import wb_platform_specific
 import wb_subversion_annotate
 import wb_subversion_info_dialog
 import wb_subversion_history
@@ -294,6 +293,7 @@ class ReportRevisionChangesProjectInfo:
         self.url = project_info.url
         self.wc_path = project_info.wc_path
         self.need_checkout = False
+        self.need_upgrade = False
 
         self.client_fg = project_info.client_fg
         self.client_bg = project_info.client_bg
