@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2006-2007 Barry A Scott.  All rights reserved.
+ Copyright (c) 2006-2011 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -23,7 +23,6 @@ import wb_exceptions
 import wb_list_panel_common
 import wb_subversion_utils
 import wb_subversion_list_handler_common
-import wb_platform_specific
 
 id_exclude = wx.NewId()
 id_include = wx.NewId()
@@ -254,6 +253,7 @@ class ReportUpdatesProjectInfo:
         self.url = project_info.url
         self.wc_path = project_info.wc_path
         self.need_checkout = False
+        self.need_upgrade = False
 
         self.client_fg = project_info.client_fg
         self.client_bg = project_info.client_bg
