@@ -114,13 +114,14 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         return wb_config.colour_status_normal
     
     def getState( self ):
-        state = wb_tree_panel.TreeState()
+        state = wb_tree_panel.TreeState( self.project_info )
 
         dir_status = self.project_info.getDirStatus()
 
         state.is_project_parent = self.is_project_parent
 
         if dir_status is None:
+            state.debug_msg = 'no dir status'
             state.modified = False
             state.new_versioned = False
             state.versioned = True
@@ -133,6 +134,8 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             state.revertable = False
 
         else:
+            state.debug_msg = 'using dir status'
+
             state.modified = True
             state.new_versioned = True
             state.versioned = True
@@ -903,11 +906,14 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         self.app.setAction( T_('Upgrade %s...') % self.project_info.wc_path )
 
         try:
+            self.app.log.info( T_('Upgrading working copy %s...') % (self.project_info.wc_path,) )
             self.project_info.client_fg.upgrade( self.project_info.wc_path )
 
         except pysvn.ClientError, e:
+            print 'error upgrade %r' % (e,)
             self.app.log_client_error( e )
 
+        self.app.log.info( T_('Upgrade complete') )
         self.app.clearProgress()
         self.app.setAction( T_('Ready') )
         self.app.refreshFrame()
