@@ -111,6 +111,12 @@ pysvn.wc_status_kind.merged:        0,
 
 prop_sort_offset = 10
 
+def wc_notify_action_lookup( action ):
+    if action in wc_notify_action_map:
+        return wc_notify_action_map[ action ]
+
+    return repr( action )
+
 wc_notify_action_map = {
     pysvn.wc_notify_action.add: 'A',
     pysvn.wc_notify_action.commit_added: 'A',
@@ -178,6 +184,15 @@ if version_info.notify_action_has_upgrade_events:
     wc_notify_action_map[ pysvn.wc_notify_action.failed_missing ] = "failed_missing"
     wc_notify_action_map[ pysvn.wc_notify_action.failed_out_of_date ] = "failed_out_of_date"
     wc_notify_action_map[ pysvn.wc_notify_action.failed_no_parent ] = "failed_no_parent"
+    wc_notify_action_map[ pysvn.wc_notify_action.failed_locked ] = "failed_locked"
+    wc_notify_action_map[ pysvn.wc_notify_action.failed_forbidden_by_server ] = "failed_forbidden_by_server"
+    wc_notify_action_map[ pysvn.wc_notify_action.skip_conflicted ] = "skip_conflicted"
+
+def wc_notify_type_lookup( action ):
+    if action in wc_notify_type_map:
+        return wc_notify_type_map[ action ]
+
+    return '?'
 
 wc_notify_type_map = {
     pysvn.wc_notify_action.add: 'A',
@@ -242,10 +257,13 @@ if version_info.notify_action_has_upgrade_events:
     wc_notify_type_map[ pysvn.wc_notify_action.url_redirect ] = None
     wc_notify_type_map[ pysvn.wc_notify_action.path_nonexistent ] = None
     wc_notify_type_map[ pysvn.wc_notify_action.exclude ] = None
-    wc_notify_type_map[ pysvn.wc_notify_action.failed_conflict ] = None
-    wc_notify_type_map[ pysvn.wc_notify_action.failed_missing ] = None
-    wc_notify_type_map[ pysvn.wc_notify_action.failed_out_of_date ] = None
-    wc_notify_type_map[ pysvn.wc_notify_action.failed_no_parent ] = None
+    wc_notify_type_map[ pysvn.wc_notify_action.failed_conflict ] = '?'
+    wc_notify_type_map[ pysvn.wc_notify_action.failed_missing ] = '?'
+    wc_notify_type_map[ pysvn.wc_notify_action.failed_out_of_date ] = '?'
+    wc_notify_type_map[ pysvn.wc_notify_action.failed_no_parent ] = '?'
+    wc_notify_type_map[ pysvn.wc_notify_action.failed_locked ] = '?'
+    wc_notify_type_map[ pysvn.wc_notify_action.failed_forbidden_by_server ] = '?'
+    wc_notify_type_map[ pysvn.wc_notify_action.skip_conflicted ] = '?'
 
 #
 #    format the concise status from file
