@@ -25,7 +25,9 @@ import wb_project_dialogs
 import wb_config
 
 class TreeState:
-    def __init__( self, place_holder=False ):
+    def __init__( self, project_info, place_holder=False ):
+        self.debug_project_info = project_info
+
         # used to tell if the state reflects a items state or is just a place holder
         self.place_holder = place_holder
 
@@ -42,10 +44,10 @@ class TreeState:
         self.is_project_parent = False
         self.revertable = False
 
-    def printState( self, title='' ):
-        print '--------', title
+    def debugPrintState( self, print_fn, title='' ):
+        print_fn( '-------- %s' % (title,) )
         for item in self.__dict__.items():
-            print 'TreeState: %s -> %r' % item
+            print_fn( 'TreeState: %s -> %r' % item )
 
 
 #--------------------------------------------------------------------------------
